@@ -1,7 +1,7 @@
 from tokenize import OP, NEWLINE
 from tokens import tokens_in
 
-def determine_imports(with_default_imports=True, without_should_dsl=False, extra_imports=None):
+def determine_imports(with_default_imports=False, with_should_dsl=False, extra_imports=None):
     default = []
 
     if extra_imports:
@@ -20,9 +20,9 @@ def determine_imports(with_default_imports=True, without_should_dsl=False, extra
         if default and tuple(default[-1]) != (OP, ';'):
             default.append((OP, ';'))
 
-        should_dsl = "from should_dsl import *;"
-        if without_should_dsl:
-            should_dsl = ""
+        should_dsl = ""
+        if with_should_dsl:
+            should_dsl = "from should_dsl import *;"
 
         default.extend(
             tokens_in('import nose; from nose.tools import *; %s from noseOfYeti.tokeniser.support import *' % should_dsl)
